:orphan:

`plasmapy.dispersion.dispersion_functions`
==========================================

.. currentmodule:: plasmapy.dispersion.dispersion_functions

.. automodapi:: plasmapy.dispersion.dispersion_functions

Example Notebooks
-----------------

.. nbgallery::

    /notebooks/dispersion/dispersion_function
